%% setData
%   set the object properties, used when copying and other places
% inputs:
%   object:Data - current object
%   grid0:Grid - Results Grid
%   grid1:Grid - Left Grid
%   grid2:Grid - Top Grid
%   name:string - Function name
%   inputs:string - input string
%   checked:boolean - typecheck status
% outputs:
%   none
% Author: Colin Eles elesc@mcmaster.ca
% Organization: McMaster Centre for Software Certification
function [] = setData(object, grid0, grid1, grid2, name, inputs, checked, multi)
object.Grid0 = grid0;
object.Grid1 = grid1;
object.Grid2 = grid2;
object.function_name = name;
object.function_inputs = inputs;
object.checked = checked;
object.multi_mode = multi;
end

